@@ -134,29 +134,49 @@ impl LinesHighlighter for ConflictsHighlighter {
 
 impl ConflictsHighlighter {
     fn render(&self, thread_pool: &ThreadPool) -> StringFuture {
-        if self.base.is_some() {
+        if !self.base.as_ref().unwrap_or(&"".to_string()).is_empty() {
+            // We have a non-empty base
             return self.render_diff3(thread_pool);
         }
 
         let c1_header = self.c1_header.clone();
         let c1 = self.c1.clone();
+        let base_header = self.base_header.clone();
         let c2_header = self.c2_header.clone();
         let c2 = self.c2.clone();
         let footer = self.footer.clone();
         return StringFuture::from_function(
             move || {
-                let (c1_tokens, c2_tokens, _, _) = refiner::to_highlighted_tokens(&c1, &c2);
-                let highlighted_c1 = token_collector::render(&LINE_STYLE_OLD, "", &c1_tokens);
+                let c1_or_newline = if c1.is_empty() { "\n" } else { &c1 };
+                let c2_or_newline = if c2.is_empty() { "\n" } else { &c2 };
+                let (c1_tokens, c2_tokens, _, _) =
+                    refiner::to_highlighted_tokens(c1_or_newline, c2_or_newline);
+
+                let c1_style = if base_header.is_empty() {
+                    LINE_STYLE_OLD
+                } else {
+                    LINE_STYLE_NEW
+                };
+                let highlighted_c1 = token_collector::render(&c1_style, "", &c1_tokens);
                 let highlighted_c2 = token_collector::render(&LINE_STYLE_NEW, "", &c2_tokens);
 
                 let mut rendered = String::new();
                 rendered.push_str(&c1_header);
                 rendered.push('\n');
-                rendered.push_str(&highlighted_c1);
+                if !c1.is_empty() {
+                    rendered.push_str(&highlighted_c1);
+                }
+
+                if !base_header.is_empty() {
+                    rendered.push_str(&base_header);
+                    rendered.push('\n');
+                }
 
                 rendered.push_str(&c2_header);
                 rendered.push('\n');
-                rendered.push_str(&highlighted_c2);
+                if !c2.is_empty() {
+                    rendered.push_str(&highlighted_c2);
+                }
 
                 rendered.push_str(&footer);
                 rendered.push('\n');
@@ -173,6 +193,7 @@ impl ConflictsHighlighter {
     ///   vs C1 or vs C2.
     /// * In section C2, we highlight additions compared to base
     fn render_diff3(&self, thread_pool: &ThreadPool) -> StringFuture {
+        assert!(self.base.is_some());
         let c1_header = self.c1_header.clone();
         let c1 = self.c1.clone();
         let base_header = self.base_header.clone();
@@ -183,12 +204,16 @@ impl ConflictsHighlighter {
 
         return StringFuture::from_function(
             move || {
+                let base_or_newline = if base.is_empty() { "\n" } else { &base };
+
+                let c1_or_newline = if c1.is_empty() { "\n" } else { &c1 };
                 let (base_vs_c1_tokens, c1_tokens, _, _) =
-                    refiner::to_highlighted_tokens(&base, &c1);
+                    refiner::to_highlighted_tokens(base_or_newline, c1_or_newline);
                 let highlighted_c1 = token_collector::render(&LINE_STYLE_NEW, "", &c1_tokens);
 
+                let c2_or_newline = if c2.is_empty() { "\n" } else { &c2 };
                 let (base_vs_c2_tokens, c2_tokens, _, _) =
-                    refiner::to_highlighted_tokens(&base, &c2);
+                    refiner::to_highlighted_tokens(base_or_newline, c2_or_newline);
                 let highlighted_c2 = token_collector::render(&LINE_STYLE_NEW, "", &c2_tokens);
 
                 assert_eq!(base_vs_c1_tokens.len(), base_vs_c2_tokens.len());
@@ -208,15 +233,21 @@ impl ConflictsHighlighter {
                 let mut rendered = String::new();
                 rendered.push_str(&c1_header);
                 rendered.push('\n');
-                rendered.push_str(&highlighted_c1);
+                if !c1.is_empty() {
+                    rendered.push_str(&highlighted_c1);
+                }
 
                 rendered.push_str(&base_header);
                 rendered.push('\n');
-                rendered.push_str(&highlighted_base);
+                if !base.is_empty() {
+                    rendered.push_str(&highlighted_base);
+                }
 
                 rendered.push_str(&c2_header);
                 rendered.push('\n');
-                rendered.push_str(&highlighted_c2);
+                if !c2.is_empty() {
+                    rendered.push_str(&highlighted_c2);
+                }
 
                 rendered.push_str(&footer);
                 rendered.push('\n');
